CKEditor5.Components.Cloud.ModulePreload (ckeditor5 v1.0.7)
View SourceA component for rendering module preload link tags in Phoenix. This component generates link tags with rel="modulepreload" for all modules in the import map. It helps browsers preload ES modules, improving performance by downloading dependencies before they are actually needed.
Summary
Functions
Renders module preload link tags for all modules in the import map. This helps browsers preload ES modules, improving performance by downloading dependencies before they are actually needed.
Functions
Renders module preload link tags for all modules in the import map. This helps browsers preload ES modules, improving performance by downloading dependencies before they are actually needed.
Attributes
preset(:string) - The name of the preset to use. Defaults to"default".nonce(:string) - The CSP nonce to use for the script tag. Defaults tonil.